@@ -10,10 +10,11 @@
 
 #include <kcompletion_export.h>
 
-#include <QObject>
-#include <QStringList>
-#include <QPointer>
 #include <QKeySequence>
+#include <QObject>
+#include <QPointer>
+#include <QStringList>
+#include <memory>
 
 class KCompTreeNode;
 class KCompletionPrivate;
@@ -151,17 +152,18 @@ public:
          * Lists all possible matches in a popup list box to choose from, and automatically
          * fills the result whenever possible.
          */
-        CompletionPopupAuto
+        CompletionPopupAuto,
     };
 
     /**
      * Constants that represent the order in which KCompletion performs
      * completion lookups.
      */
-    enum CompOrder { Sorted,    ///< Use alphabetically sorted order
-                     Insertion, ///< Use order of insertion
-                     Weighted   ///< Use weighted order
-                   };
+    enum CompOrder {
+        Sorted, ///< Use alphabetically sorted order
+        Insertion, ///< Use order of insertion
+        Weighted, ///< Use weighted order
+    };
     Q_ENUM(CompOrder)
 
     /**
@@ -277,6 +279,15 @@ public:
      */
     bool ignoreCase() const;
 
+    /**
+     * Informs the caller if they should display the auto-suggestion for the last completion operation performed.
+     * Applies for CompletionPopupAuto and CompletionAuto modes.
+     * Defaults to true, but deriving classes may set it to false in special cases via "setShouldAutoSuggest".
+     * @return true if auto-suggestion should be displayed for the last completion operation performed.
+     * @since 5.87
+     */
+    bool shouldAutoSuggest() const;
+
     /**
      * Returns a list of all items matching the last completed string.
      * It might take some time if you have a @em lot of items.
@@ -396,9 +407,9 @@ public Q_SLOTS:
      * @deprecated since 5.0, use makeCompletion() instead
      */
     KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use KCompletion::makeCompletion(const QString &)")
-    void slotMakeCompletion(const QString &string)     //inline (redirect)
+    void slotMakeCompletion(const QString &string) // inline (redirect)
     {
-        (void) makeCompletion(string);
+        (void)makeCompletion(string);
     }
 #endif
 
@@ -410,9 +421,9 @@ public Q_SLOTS:
      * @deprecated since 5.0, use previousMatch() instead
      */
     KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use KCompletion::previousMatch()")
-    void slotPreviousMatch()   //inline (redirect)
+    void slotPreviousMatch() // inline (redirect)
     {
-        (void) previousMatch();
+        (void)previousMatch();
     }
 #endif
 
@@ -424,9 +435,9 @@ public Q_SLOTS:
      * @deprecated since 5.0, use nextMatch() instead
      */
     KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use KCompletion::nextMatch()")
-    void slotNextMatch()   //inline (redirect)
+    void slotNextMatch() // inline (redirect)
     {
-        (void) nextMatch();
+        (void)nextMatch();
     }
 #endif
 
@@ -493,7 +504,7 @@ Q_SIGNALS:
      *
      * In particular, makeCompletion(), previousMatch() and nextMatch()
      * all emit this signal; makeCompletion() will only emit it when a
-     * match is found, but the other methods will alwasy emit it (and so
+     * match is found, but the other methods will always emit it (and so
      * may emit it with an empty string).
      *
      * @param item the matching item, or QString() if there were no more
@@ -556,9 +567,18 @@ protected:
      */
     virtual void postProcessMatches(KCompletionMatches *matches) const;
 
+    /**
+     * Deriving classes may set this property and control whether the auto-suggestion should be displayed
+     * for the last completion operation performed.
+     *
+     * Applies for CompletionPopupAuto and CompletionAuto modes.
+     * @since 5.87
+     */
+    void setShouldAutoSuggest(bool shouldAutosuggest);
+
 private:
     Q_DISABLE_COPY(KCompletion)
-    const QScopedPointer<KCompletionPrivate> d_ptr;
+    std::unique_ptr<KCompletionPrivate> const d_ptr;
 };
 
 #endif // KCOMPLETION_H
