@@ -2,17 +2,17 @@
 
 #include <assert.h>
 
-#include <KConfigGroup>
 #include <KConfig>
+#include <KConfigGroup>
 
 #include <QApplication>
-#include <QPushButton>
-#include <QLayout>
-#include <QPixmap>
-#include <QLabel>
-#include <QTimer>
 #include <QBoxLayout>
 #include <QDebug>
+#include <QLabel>
+#include <QLayout>
+#include <QPixmap>
+#include <QPushButton>
+#include <QTimer>
 
 #include <khistorycombobox.h>
 
@@ -109,10 +109,10 @@ KComboBoxTest::KComboBoxTest(QWidget *widget)
 
     vbox->addLayout(hbox);
 
-    // Popuplate the select-only list box
+    // Populate the select-only list box
     QStringList list;
-    list << QStringLiteral("Stone") << QStringLiteral("Tree") << QStringLiteral("Peables") << QStringLiteral("Ocean") << QStringLiteral("Sand") << QStringLiteral("Chips")
-         << QStringLiteral("Computer") << QStringLiteral("Mankind");
+    list << QStringLiteral("Stone") << QStringLiteral("Tree") << QStringLiteral("Peables") << QStringLiteral("Ocean") << QStringLiteral("Sand")
+         << QStringLiteral("Chips") << QStringLiteral("Computer") << QStringLiteral("Mankind");
     list.sort();
 
     // Setup the qcombobox
@@ -160,7 +160,9 @@ void KComboBoxTest::connectComboSignals(QComboBox *combo)
     QObject::connect(combo, SIGNAL(activated(QString)), SLOT(slotActivated(QString)));
     QObject::connect(combo, SIGNAL(currentIndexChanged(int)), SLOT(slotCurrentIndexChanged(int)));
     QObject::connect(combo, SIGNAL(currentIndexChanged(QString)), SLOT(slotCurrentIndexChanged(QString)));
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
     QObject::connect(combo, SIGNAL(returnPressed()), SLOT(slotReturnPressed()));
+#endif
     QObject::connect(combo, SIGNAL(returnPressed(QString)), SLOT(slotReturnPressed(QString)));
 }
 
@@ -215,10 +217,12 @@ void KComboBoxTest::slotActivated(const QString &item)
     qDebug() << "Activated Combo:" << qPrintable(sender()->objectName()) << ", item:" << item;
 }
 
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
 void KComboBoxTest::slotReturnPressed()
 {
     qDebug() << "Return Pressed:" << qPrintable(sender()->objectName());
 }
+#endif
 
 void KComboBoxTest::slotReturnPressed(const QString &item)
 {
@@ -240,4 +244,3 @@ int main(int argc, char **argv)
     t->show();
     return a.exec();
 }
-
